.. currentmodule:: sardana.pool.poolioregister

.. _sardana-ior-api:

=============================
I/O register API reference
=============================

.. todo:: document I/O register API reference

.. seealso:: 
    
    :ref:`sardana-ior-overview`
        the I/O register overview 
    
    :class:`~sardana.tango.pool.IORegister.IORegister`
        the I/O register tango device :term:`API`

..    :class:`~sardana.pool.poolioregister.PoolIORegister`
..        the I/O register class :term:`API`
